HTTPower.Error (HTTPower v0.16.0)
View SourceHTTP error struct from HTTPower.
This struct provides a clean abstraction for all possible HTTP errors, whether they're network issues, timeouts, or other problems.
HTTP error struct from HTTPower.
This struct provides a clean abstraction for all possible HTTP errors, whether they're network issues, timeouts, or other problems.